@@ -9,13 +9,22 @@ use base qw( Log::Dispatch::Output );
 use Params::Validate qw(validate);
 Params::Validate::validation_options( allow_extra => 1 );
 
-use Apache::Log;
-
 use vars qw[ $VERSION ];
 
-$VERSION = sprintf "%d.%02d", q$Revision: 1.9 $ =~ /: (\d+)\.(\d+)/;
+$VERSION = '1.09';
+
+BEGIN
+{
+    if ( $ENV{MOD_PERL} && $ENV{MOD_PERL} =~ /^2/ )
+    {
+        require Apache2::Log;
+    }
+    else
+    {
+        require Apache::Log;
+    }
+}
 
-1;
 
 sub new
 {
@@ -32,38 +41,28 @@ sub new
     return $self;
 }
 
-sub log_message
 {
-    my $self = shift;
-    my %p = @_;
+    my %methods =
+        ( emergency => 'emerg',
+          critical  => 'crit',
+          warning   => 'warn',
+        );
+    sub log_message
+    {
+        my $self = shift;
+        my %p = @_;
 
-    my $method;
+        my $level = $self->_level_as_name($p{level});
 
-    my $level = $self->_level_as_name($p{level});
-    if ($level eq 'emergency')
-    {
-	$method = 'emerg';
-    }
-    elsif ( $level eq 'critical' )
-    {
-	$method = 'crit';
-    }
-    elsif( $level eq 'err' )
-    {
-	$method = 'error';
-    }
-    elsif( $level eq 'warning' )
-    {
-	$method = 'warn';
-    }
-    else
-    {
-	$method = $level;
-    }
+        my $method = $methods{$level} || $level;
 
-    $self->{apache_log}->$method( $p{message} );
+        $self->{apache_log}->$method( $p{message} );
+    }
 }
 
+
+1;
+
 __END__
 
 =head1 NAME
@@ -103,12 +102,12 @@ The name of the object (not the filename!).  Required.
 =item * min_level ($)
 
 The minimum logging level this object will accept.  See the
-Log::Dispatch documentation for more information.  Required.
+Log::Dispatch documentation on L<Log Levels|Log::Dispatch/"Log Levels"> for more information.  Required.
 
 =item * max_level ($)
 
 The maximum logging level this obejct will accept.  See the
-Log::Dispatch documentation for more information.  This is not
+Log::Dispatch documentation on L<Log Levels|Log::Dispatch/"Log Levels"> for more information.  This is not
 required.  By default the maximum is the highest possible level (which
 means functionally that the object has no maximum).
 
